[qpid-broker-j] branch main updated: NO-JIRA: Update Qpid JMS client to version 0.59.0

2021-08-24 Thread orudyy
This is an automated email from the ASF dual-hosted git repository.

orudyy pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/qpid-broker-j.git


The following commit(s) were added to refs/heads/main by this push:
 new d711a17  NO-JIRA: Update Qpid JMS client to version 0.59.0
d711a17 is described below

commit d711a172ba1801ef97a4e6668c8e2b11feb001c0
Author: Alex Rudyy 
AuthorDate: Tue Aug 24 23:54:04 2021 +0100

NO-JIRA: Update Qpid JMS client to version 0.59.0
---
 pom.xml | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/pom.xml b/pom.xml
index 1eacc38..b98d93c 100644
--- a/pom.xml
+++ b/pom.xml
@@ -130,12 +130,12 @@
 
 4.13
 3.2.4
-4.1.51.Final
+4.1.63.Final
 2.2
 3.5.4
 1.1.1
 4.5.3
-0.54.0
+0.59.0
 6.3.4
 2.3.1
 

-
To unsubscribe, e-mail: commits-unsubscr...@qpid.apache.org
For additional commands, e-mail: commits-h...@qpid.apache.org



[qpid-protonj2] branch main updated: NO-JIRA Attempt to fix a test timing issus that fails CI

2021-08-24 Thread tabish
This is an automated email from the ASF dual-hosted git repository.

tabish pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/qpid-protonj2.git


The following commit(s) were added to refs/heads/main by this push:
 new 1cc9f2b  NO-JIRA Attempt to fix a test timing issus that fails CI
1cc9f2b is described below

commit 1cc9f2ba0a7a316455f116ff0cc6c901b43860ce
Author: Timothy Bish 
AuthorDate: Tue Aug 24 18:19:54 2021 -0400

NO-JIRA Attempt to fix a test timing issus that fails CI
---
 .../test/java/org/apache/qpid/protonj2/client/impl/ReceiverTest.java   | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git 
a/protonj2-client/src/test/java/org/apache/qpid/protonj2/client/impl/ReceiverTest.java
 
b/protonj2-client/src/test/java/org/apache/qpid/protonj2/client/impl/ReceiverTest.java
index 1c2636a..a90f027 100644
--- 
a/protonj2-client/src/test/java/org/apache/qpid/protonj2/client/impl/ReceiverTest.java
+++ 
b/protonj2-client/src/test/java/org/apache/qpid/protonj2/client/impl/ReceiverTest.java
@@ -600,7 +600,8 @@ public class ReceiverTest extends ImperativeClientTestCase {
 Matcher drainMatcher = anyOf(equalTo(false), nullValue());
 peer.expectFlow().withDrain(drainMatcher).withLinkCredit(credit);
 
-receiver.addCredit(credit);
+// Ensure we get the attach response with the initial delivery 
count.
+receiver.openFuture().get().addCredit(credit);
 
 peer.waitForScriptToComplete(5, TimeUnit.SECONDS);
 

-
To unsubscribe, e-mail: commits-unsubscr...@qpid.apache.org
For additional commands, e-mail: commits-h...@qpid.apache.org



[qpid-protonj2] branch main updated: PROTON-2419 Use HTTPS where possible in project Maven pom.xml files

2021-08-24 Thread tabish
This is an automated email from the ASF dual-hosted git repository.

tabish pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/qpid-protonj2.git


The following commit(s) were added to refs/heads/main by this push:
 new 6127af3  PROTON-2419 Use HTTPS where possible in project Maven pom.xml 
files
 new 5f2c906  This closes #3
6127af3 is described below

commit 6127af344ea2e068c98dfd6cfa71788154bdeefb
Author: Jiri Danek 
AuthorDate: Tue Aug 24 22:02:33 2021 +0200

PROTON-2419 Use HTTPS where possible in project Maven pom.xml files
---
 apache-qpid-protonj2/pom.xml | 2 +-
 pom.xml  | 6 +++---
 protonj2-client-docs/pom.xml | 2 +-
 protonj2-client/pom.xml  | 2 +-
 protonj2/pom.xml | 2 +-
 5 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/apache-qpid-protonj2/pom.xml b/apache-qpid-protonj2/pom.xml
index 00f3b90..93a3894 100644
--- a/apache-qpid-protonj2/pom.xml
+++ b/apache-qpid-protonj2/pom.xml
@@ -14,7 +14,7 @@
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
--->http://maven.apache.org/POM/4.0.0; 
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance; 
xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 
http://maven.apache.org/maven-v4_0_0.xsd;>
+-->http://maven.apache.org/POM/4.0.0; 
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance; 
xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 
https://maven.apache.org/maven-v4_0_0.xsd;>
   
 org.apache.qpid
 protonj2-parent
diff --git a/pom.xml b/pom.xml
index 5613679..728a25a 100644
--- a/pom.xml
+++ b/pom.xml
@@ -14,7 +14,7 @@
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
--->http://maven.apache.org/POM/4.0.0; 
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance; 
xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 
http://maven.apache.org/maven-v4_0_0.xsd;>
+-->http://maven.apache.org/POM/4.0.0; 
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance; 
xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 
https://maven.apache.org/maven-v4_0_0.xsd;>
 
   
 org.apache
@@ -66,9 +66,9 @@
 -Xmx2g -enableassertions ${jacoco-config}
   
 
-  http://qpid.apache.org/proton
+  https://qpid.apache.org/proton
   
-
scm:git:http://git-wip-us.apache.org/repos/asf/qpid-protonj2.git
+
scm:git:https://git-wip-us.apache.org/repos/asf/qpid-protonj2.git
 
scm:git:https://git-wip-us.apache.org/repos/asf/qpid-protonj2.git
 https://git-wip-us.apache.org/repos/asf?p=qpid-protonj2.git
 1.0.0-M2
diff --git a/protonj2-client-docs/pom.xml b/protonj2-client-docs/pom.xml
index f6b47d4..ec7d554 100644
--- a/protonj2-client-docs/pom.xml
+++ b/protonj2-client-docs/pom.xml
@@ -14,7 +14,7 @@
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
--->http://maven.apache.org/POM/4.0.0; 
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance; 
xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 
http://maven.apache.org/maven-v4_0_0.xsd;>
+-->http://maven.apache.org/POM/4.0.0; 
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance; 
xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 
https://maven.apache.org/maven-v4_0_0.xsd;>
   
 org.apache.qpid
 protonj2-parent
diff --git a/protonj2-client/pom.xml b/protonj2-client/pom.xml
index 66c5c1b..c7cd536 100644
--- a/protonj2-client/pom.xml
+++ b/protonj2-client/pom.xml
@@ -15,7 +15,7 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 -->
-http://maven.apache.org/POM/4.0.0; 
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance; 
xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 
http://maven.apache.org/maven-v4_0_0.xsd;>
+http://maven.apache.org/POM/4.0.0; 
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance; 
xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 
https://maven.apache.org/maven-v4_0_0.xsd;>
 
   4.0.0
 
diff --git a/protonj2/pom.xml b/protonj2/pom.xml
index ecceb46..532c8da 100644
--- a/protonj2/pom.xml
+++ b/protonj2/pom.xml
@@ -15,7 +15,7 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 -->
-http://maven.apache.org/POM/4.0.0; 
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance; 
xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 
http://maven.apache.org/maven-v4_0_0.xsd;>
+http://maven.apache.org/POM/4.0.0; 
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance; 
xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 
https://maven.apache.org/maven-v4_0_0.xsd;>
   
 org.apache.qpid
 protonj2-parent

-
To 

[qpid-protonj2] branch main updated: PROTON-2394 Update proton buffer API Javadocs to align terminology

2021-08-24 Thread tabish
This is an automated email from the ASF dual-hosted git repository.

tabish pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/qpid-protonj2.git


The following commit(s) were added to refs/heads/main by this push:
 new acfb425  PROTON-2394 Update proton buffer API Javadocs to align 
terminology
acfb425 is described below

commit acfb4252948b479edb3bd0587b2356299ecd0f27
Author: Timothy Bish 
AuthorDate: Tue Aug 24 17:12:24 2021 -0400

PROTON-2394 Update proton buffer API Javadocs to align terminology

Use consistent offset naming for all buffer read / write APIs with
bounds parameters.  Fixses some code references to refer to the right
names and clarifies a few method APIs
---
 .../apache/qpid/protonj2/buffer/ProtonBuffer.java  | 62 +++---
 1 file changed, 32 insertions(+), 30 deletions(-)

diff --git 
a/protonj2-client/src/main/java/org/apache/qpid/protonj2/client/TransportOptions.java
 
b/protonj2-client/src/main/java/org/apache/qpid/protonj2/client/TransportOptions.java
index f2624dc..489147a 100644
--- 
a/protonj2-client/src/main/java/org/apache/qpid/protonj2/client/TransportOptions.java
+++ 
b/protonj2-client/src/main/java/org/apache/qpid/protonj2/client/TransportOptions.java
@@ -16,7 +16,10 @@
  */
 package org.apache.qpid.protonj2.client;
 
+import java.util.Arrays;
+import java.util.Collections;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 
 /**
@@ -38,7 +41,9 @@ public class TransportOptions implements Cloneable {
 public static final int DEFAULT_LOCAL_PORT = 0;
 public static final boolean DEFAULT_USE_WEBSOCKETS = false;
 public static final int DEFAULT_WEBSOCKET_MAX_FRAME_SIZE = 65535;
-public static final String[] DEFAULT_NATIVEIO_PREFERENCES = { "EPOLL", 
"KQUEUE" };
+private static final String[] DEFAULT_NATIVEIO_PREFERENCES_ARRAY = { 
"EPOLL", "KQUEUE" };
+public static final List DEFAULT_NATIVEIO_PREFERENCES =
+Collections.unmodifiableList(Arrays.asList( 
DEFAULT_NATIVEIO_PREFERENCES_ARRAY ));
 
 private int sendBufferSize = DEFAULT_SEND_BUFFER_SIZE;
 private int receiveBufferSize = DEFAULT_RECEIVE_BUFFER_SIZE;
@@ -52,7 +57,7 @@ public class TransportOptions implements Cloneable {
 private String localAddress;
 private int localPort = DEFAULT_LOCAL_PORT;
 private boolean allowNativeIO = DEFAULT_ALLOW_NATIVE_IO;
-private String[] nativeIOPeference = DEFAULT_NATIVEIO_PREFERENCES;
+private String[] nativeIOPreference = DEFAULT_NATIVEIO_PREFERENCES_ARRAY;
 private boolean traceBytes = DEFAULT_TRACE_BYTES;
 private boolean useWebSockets = DEFAULT_USE_WEBSOCKETS;
 private String webSocketPath;
@@ -331,18 +336,18 @@ public class TransportOptions implements Cloneable {
 /**
  * @return the nativeIOPeference
  */
-public String[] nativeIOPeference() {
-return nativeIOPeference;
+public String[] nativeIOPreference() {
+return nativeIOPreference;
 }
 
 /**
  * @param nativeIOPeference the nativeIOPeference to set
  */
-public void nativeIOPeference(String... nativeIOPeference) {
+public void nativeIOPreference(String... nativeIOPeference) {
 if (nativeIOPeference == null || nativeIOPeference.length == 0 || 
nativeIOPeference.length == 1 && nativeIOPeference[0] == null) {
-this.nativeIOPeference = DEFAULT_NATIVEIO_PREFERENCES;
+this.nativeIOPreference = DEFAULT_NATIVEIO_PREFERENCES_ARRAY;
 } else {
-this.nativeIOPeference = nativeIOPeference;
+this.nativeIOPreference = nativeIOPeference;
 }
 }
 
@@ -468,7 +473,7 @@ public class TransportOptions implements Cloneable {
  

svn commit: r49626 - in /dev/qpid/broker-j/8.0.6-rc1: ./ binaries/

2021-08-24 Thread orudyy
Author: orudyy
Date: Tue Aug 24 20:19:50 2021
New Revision: 49626

Log:
Apache Qpid Broker-J 8.0.6 RC1

Added:
dev/qpid/broker-j/8.0.6-rc1/
dev/qpid/broker-j/8.0.6-rc1/apache-qpid-broker-j-8.0.6-src.tar.gz   (with 
props)
dev/qpid/broker-j/8.0.6-rc1/apache-qpid-broker-j-8.0.6-src.tar.gz.asc   
(with props)
dev/qpid/broker-j/8.0.6-rc1/apache-qpid-broker-j-8.0.6-src.tar.gz.sha512
dev/qpid/broker-j/8.0.6-rc1/binaries/
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.tar.gz  
 (with props)

dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.tar.gz.asc  
 (with props)

dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.tar.gz.sha512
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.zip   
(with props)
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.zip.asc 
  (with props)

dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.zip.sha512

Added: dev/qpid/broker-j/8.0.6-rc1/apache-qpid-broker-j-8.0.6-src.tar.gz
==
Binary file - no diff available.

Propchange: dev/qpid/broker-j/8.0.6-rc1/apache-qpid-broker-j-8.0.6-src.tar.gz
--
svn:mime-type = application/gzip

Added: dev/qpid/broker-j/8.0.6-rc1/apache-qpid-broker-j-8.0.6-src.tar.gz.asc
==
Binary file - no diff available.

Propchange: 
dev/qpid/broker-j/8.0.6-rc1/apache-qpid-broker-j-8.0.6-src.tar.gz.asc
--
svn:mime-type = application/pgp-signature

Added: dev/qpid/broker-j/8.0.6-rc1/apache-qpid-broker-j-8.0.6-src.tar.gz.sha512
==
--- dev/qpid/broker-j/8.0.6-rc1/apache-qpid-broker-j-8.0.6-src.tar.gz.sha512 
(added)
+++ dev/qpid/broker-j/8.0.6-rc1/apache-qpid-broker-j-8.0.6-src.tar.gz.sha512 
Tue Aug 24 20:19:50 2021
@@ -0,0 +1 @@
+a490952e9a19ddc6f47024bdf96cf064926a319befef5f8528caf2ff9864a37668109ce0361ccf82215125aed3434183da16e2ddaa553d313eb1d1c4d05ecf04
  apache-qpid-broker-j-8.0.6-src.tar.gz

Added: 
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.tar.gz
==
Binary file - no diff available.

Propchange: 
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.tar.gz
--
svn:mime-type = application/gzip

Added: 
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.tar.gz.asc
==
Binary file - no diff available.

Propchange: 
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.tar.gz.asc
--
svn:mime-type = application/pgp-signature

Added: 
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.tar.gz.sha512
==
--- 
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.tar.gz.sha512
 (added)
+++ 
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.tar.gz.sha512
 Tue Aug 24 20:19:50 2021
@@ -0,0 +1 @@
+6dc44b5a26b5e7e5890ced3d9a19e222cd90245381e333c2d32d0903c56212e2328e489644ded2291bd2982e33c528df8b9e42032ee35b372d099e85afcdae5b
  apache-qpid-broker-j-8.0.6-bin.tar.gz

Added: dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.zip
==
Binary file - no diff available.

Propchange: 
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.zip
--
svn:mime-type = application/zip

Added: 
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.zip.asc
==
Binary file - no diff available.

Propchange: 
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.zip.asc
--
svn:mime-type = application/pgp-signature

Added: 
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.zip.sha512
==
--- 
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.zip.sha512 
(added)
+++ 
dev/qpid/broker-j/8.0.6-rc1/binaries/apache-qpid-broker-j-8.0.6-bin.zip.sha512 
Tue Aug 24 20:19:50 2021
@@ -0,0 +1 @@

svn commit: r49625 - in /dev/qpid/broker-j: 7.0.8-rc1/ 7.0.9-rc1/ 7.1.10-rc1/ 7.1.11-rc1/ 7.1.12-rc1/ 7.1.8-rc1/ 7.1.9-rc1/ 8.0.0-rc1/ 8.0.1-rc1/ 8.0.2-rc1/ 8.0.3-rc1/ 8.0.4-rc1/

2021-08-24 Thread orudyy
Author: orudyy
Date: Tue Aug 24 20:09:49 2021
New Revision: 49625

Log:
Remove old release candidate binaries for Qpid Broker-J

Removed:
dev/qpid/broker-j/7.0.8-rc1/
dev/qpid/broker-j/7.0.9-rc1/
dev/qpid/broker-j/7.1.10-rc1/
dev/qpid/broker-j/7.1.11-rc1/
dev/qpid/broker-j/7.1.12-rc1/
dev/qpid/broker-j/7.1.8-rc1/
dev/qpid/broker-j/7.1.9-rc1/
dev/qpid/broker-j/8.0.0-rc1/
dev/qpid/broker-j/8.0.1-rc1/
dev/qpid/broker-j/8.0.2-rc1/
dev/qpid/broker-j/8.0.3-rc1/
dev/qpid/broker-j/8.0.4-rc1/


-
To unsubscribe, e-mail: commits-unsubscr...@qpid.apache.org
For additional commands, e-mail: commits-h...@qpid.apache.org



[qpid-broker-j] branch 8.0.x updated: [maven-release-plugin] prepare for next development iteration

2021-08-24 Thread orudyy
This is an automated email from the ASF dual-hosted git repository.

orudyy pushed a commit to branch 8.0.x
in repository https://gitbox.apache.org/repos/asf/qpid-broker-j.git


The following commit(s) were added to refs/heads/8.0.x by this push:
 new 5f11661  [maven-release-plugin] prepare for next development iteration
5f11661 is described below

commit 5f11661b528e6442bd36c2e5231c3178aa399571
Author: Alex Rudyy 
AuthorDate: Tue Aug 24 20:48:01 2021 +0100

[maven-release-plugin] prepare for next development iteration
---
 apache-qpid-broker-j/pom.xml | 2 +-
 bdbstore/pom.xml | 2 +-
 bdbstore/systests/pom.xml| 2 +-
 broker-codegen/pom.xml   | 2 +-
 broker-core/pom.xml  | 2 +-
 broker-plugins/access-control/pom.xml| 2 +-
 broker-plugins/amqp-0-10-protocol/pom.xml| 2 +-
 broker-plugins/amqp-0-8-protocol/pom.xml | 2 +-
 broker-plugins/amqp-1-0-bdb-store/pom.xml| 2 +-
 broker-plugins/amqp-1-0-jdbc-store/pom.xml   | 2 +-
 broker-plugins/amqp-1-0-protocol/pom.xml | 2 +-
 broker-plugins/amqp-msg-conv-0-10-to-1-0/pom.xml | 2 +-
 broker-plugins/amqp-msg-conv-0-8-to-0-10/pom.xml | 2 +-
 broker-plugins/amqp-msg-conv-0-8-to-1-0/pom.xml  | 2 +-
 broker-plugins/derby-store/pom.xml   | 2 +-
 broker-plugins/jdbc-logging-logback/pom.xml  | 2 +-
 broker-plugins/jdbc-provider-bone/pom.xml| 2 +-
 broker-plugins/jdbc-store/pom.xml| 2 +-
 broker-plugins/logging-logback/pom.xml   | 2 +-
 broker-plugins/management-amqp/pom.xml   | 2 +-
 broker-plugins/management-http/pom.xml   | 2 +-
 broker-plugins/memory-store/pom.xml  | 2 +-
 broker-plugins/prometheus-exporter/pom.xml   | 2 +-
 broker-plugins/websocket/pom.xml | 2 +-
 broker/pom.xml   | 2 +-
 doc/developer-guide/pom.xml  | 2 +-
 doc/java-broker/pom.xml  | 2 +-
 doc/java-perftests/pom.xml   | 2 +-
 doc/pom.xml  | 2 +-
 joramtests/pom.xml   | 2 +-
 perftests/pom.xml| 2 +-
 perftests/visualisation-jfc/pom.xml  | 2 +-
 pom.xml  | 4 ++--
 qpid-perftests-systests/pom.xml  | 2 +-
 qpid-systests-parent/pom.xml | 4 ++--
 qpid-test-utils/pom.xml  | 2 +-
 systests/end-to-end-conversion-tests/pom.xml | 2 +-
 systests/protocol-tests-amqp-0-10/pom.xml| 2 +-
 systests/protocol-tests-amqp-0-8/pom.xml | 2 +-
 systests/protocol-tests-amqp-1-0/pom.xml | 2 +-
 systests/protocol-tests-core/pom.xml | 2 +-
 systests/qpid-systests-http-management/pom.xml   | 2 +-
 systests/qpid-systests-jms-core/pom.xml  | 2 +-
 systests/qpid-systests-jms_1.1/pom.xml   | 2 +-
 systests/qpid-systests-jms_2.0/pom.xml   | 2 +-
 systests/qpid-systests-spawn-admin/pom.xml   | 2 +-
 systests/systests-utils/pom.xml  | 2 +-
 tck/pom.xml  | 2 +-
 tools/pom.xml| 2 +-
 49 files changed, 51 insertions(+), 51 deletions(-)

diff --git a/apache-qpid-broker-j/pom.xml b/apache-qpid-broker-j/pom.xml
index ef4bce0..70d51a4 100644
--- a/apache-qpid-broker-j/pom.xml
+++ b/apache-qpid-broker-j/pom.xml
@@ -18,7 +18,7 @@
   
 org.apache.qpid
 qpid-broker-parent
-8.0.6
+8.0.7-SNAPSHOT
   
   4.0.0
 
diff --git a/bdbstore/pom.xml b/bdbstore/pom.xml
index 2229ed8..27d4e2d 100644
--- a/bdbstore/pom.xml
+++ b/bdbstore/pom.xml
@@ -21,7 +21,7 @@
   
 org.apache.qpid
 qpid-broker-parent
-8.0.6
+8.0.7-SNAPSHOT
   
 
   qpid-bdbstore
diff --git a/bdbstore/systests/pom.xml b/bdbstore/systests/pom.xml
index 4d77176..1ebaffd 100644
--- a/bdbstore/systests/pom.xml
+++ b/bdbstore/systests/pom.xml
@@ -21,7 +21,7 @@
   
 org.apache.qpid
 qpid-systests-parent
-8.0.6
+8.0.7-SNAPSHOT
 ../../qpid-systests-parent/pom.xml
   
 
diff --git a/broker-codegen/pom.xml b/broker-codegen/pom.xml
index febddc6..224a9fb 100644
--- a/broker-codegen/pom.xml
+++ b/broker-codegen/pom.xml
@@ -21,7 +21,7 @@
   
 org.apache.qpid
 qpid-broker-parent
-8.0.6
+8.0.7-SNAPSHOT
   
 
   qpid-broker-codegen
diff --git a/broker-core/pom.xml b/broker-core/pom.xml
index 383ed52..d1171a5 100644
--- a/broker-core/pom.xml
+++ b/broker-core/pom.xml
@@ -21,7 +21,7 @@
   
 org.apache.qpid
 qpid-broker-parent
-8.0.6
+8.0.7-SNAPSHOT
   
 
   qpid-broker-core
diff --git a/broker-plugins/access-control/pom.xml 
b/broker-plugins/access-control/pom.xml
index e7ad76f..36afcbc 100644
--- a/broker-plugins/access-control/pom.xml
+++ b/broker-plugins/access-control/pom.xml
@@ -21,7 +21,7 @@
   
   

[qpid-broker-j] annotated tag 8.0.6 created (now 4c34e1d)

2021-08-24 Thread orudyy
This is an automated email from the ASF dual-hosted git repository.

orudyy pushed a change to annotated tag 8.0.6
in repository https://gitbox.apache.org/repos/asf/qpid-broker-j.git.


  at 4c34e1d  (tag)
 tagging 1bd1c16b2a7f2743a947ee4a4acd4d62f2ab65ba (commit)
 replaces 8.0.5
  by Alex Rudyy
  on Tue Aug 24 20:47:57 2021 +0100

- Log -
[maven-release-plugin] copy for tag 8.0.6
---

No new revisions were added by this update.

-
To unsubscribe, e-mail: commits-unsubscr...@qpid.apache.org
For additional commands, e-mail: commits-h...@qpid.apache.org



[qpid-broker-j] branch 8.0.x updated: [maven-release-plugin] prepare release 8.0.6

2021-08-24 Thread orudyy
This is an automated email from the ASF dual-hosted git repository.

orudyy pushed a commit to branch 8.0.x
in repository https://gitbox.apache.org/repos/asf/qpid-broker-j.git


The following commit(s) were added to refs/heads/8.0.x by this push:
 new 1bd1c16  [maven-release-plugin] prepare release 8.0.6
1bd1c16 is described below

commit 1bd1c16b2a7f2743a947ee4a4acd4d62f2ab65ba
Author: Alex Rudyy 
AuthorDate: Tue Aug 24 20:47:38 2021 +0100

[maven-release-plugin] prepare release 8.0.6
---
 apache-qpid-broker-j/pom.xml | 2 +-
 bdbstore/pom.xml | 2 +-
 bdbstore/systests/pom.xml| 2 +-
 broker-codegen/pom.xml   | 2 +-
 broker-core/pom.xml  | 2 +-
 broker-plugins/access-control/pom.xml| 2 +-
 broker-plugins/amqp-0-10-protocol/pom.xml| 2 +-
 broker-plugins/amqp-0-8-protocol/pom.xml | 2 +-
 broker-plugins/amqp-1-0-bdb-store/pom.xml| 2 +-
 broker-plugins/amqp-1-0-jdbc-store/pom.xml   | 2 +-
 broker-plugins/amqp-1-0-protocol/pom.xml | 2 +-
 broker-plugins/amqp-msg-conv-0-10-to-1-0/pom.xml | 2 +-
 broker-plugins/amqp-msg-conv-0-8-to-0-10/pom.xml | 2 +-
 broker-plugins/amqp-msg-conv-0-8-to-1-0/pom.xml  | 2 +-
 broker-plugins/derby-store/pom.xml   | 2 +-
 broker-plugins/jdbc-logging-logback/pom.xml  | 2 +-
 broker-plugins/jdbc-provider-bone/pom.xml| 2 +-
 broker-plugins/jdbc-store/pom.xml| 2 +-
 broker-plugins/logging-logback/pom.xml   | 2 +-
 broker-plugins/management-amqp/pom.xml   | 2 +-
 broker-plugins/management-http/pom.xml   | 2 +-
 broker-plugins/memory-store/pom.xml  | 2 +-
 broker-plugins/prometheus-exporter/pom.xml   | 2 +-
 broker-plugins/websocket/pom.xml | 2 +-
 broker/pom.xml   | 2 +-
 doc/developer-guide/pom.xml  | 2 +-
 doc/java-broker/pom.xml  | 2 +-
 doc/java-perftests/pom.xml   | 2 +-
 doc/pom.xml  | 2 +-
 joramtests/pom.xml   | 2 +-
 perftests/pom.xml| 2 +-
 perftests/visualisation-jfc/pom.xml  | 2 +-
 pom.xml  | 4 ++--
 qpid-perftests-systests/pom.xml  | 2 +-
 qpid-systests-parent/pom.xml | 4 ++--
 qpid-test-utils/pom.xml  | 2 +-
 systests/end-to-end-conversion-tests/pom.xml | 2 +-
 systests/protocol-tests-amqp-0-10/pom.xml| 2 +-
 systests/protocol-tests-amqp-0-8/pom.xml | 2 +-
 systests/protocol-tests-amqp-1-0/pom.xml | 2 +-
 systests/protocol-tests-core/pom.xml | 2 +-
 systests/qpid-systests-http-management/pom.xml   | 2 +-
 systests/qpid-systests-jms-core/pom.xml  | 2 +-
 systests/qpid-systests-jms_1.1/pom.xml   | 2 +-
 systests/qpid-systests-jms_2.0/pom.xml   | 2 +-
 systests/qpid-systests-spawn-admin/pom.xml   | 2 +-
 systests/systests-utils/pom.xml  | 2 +-
 tck/pom.xml  | 2 +-
 tools/pom.xml| 2 +-
 49 files changed, 51 insertions(+), 51 deletions(-)

diff --git a/apache-qpid-broker-j/pom.xml b/apache-qpid-broker-j/pom.xml
index 6f56976..ef4bce0 100644
--- a/apache-qpid-broker-j/pom.xml
+++ b/apache-qpid-broker-j/pom.xml
@@ -18,7 +18,7 @@
   
 org.apache.qpid
 qpid-broker-parent
-8.0.6-SNAPSHOT
+8.0.6
   
   4.0.0
 
diff --git a/bdbstore/pom.xml b/bdbstore/pom.xml
index 28886d9..2229ed8 100644
--- a/bdbstore/pom.xml
+++ b/bdbstore/pom.xml
@@ -21,7 +21,7 @@
   
 org.apache.qpid
 qpid-broker-parent
-8.0.6-SNAPSHOT
+8.0.6
   
 
   qpid-bdbstore
diff --git a/bdbstore/systests/pom.xml b/bdbstore/systests/pom.xml
index c0f111d..4d77176 100644
--- a/bdbstore/systests/pom.xml
+++ b/bdbstore/systests/pom.xml
@@ -21,7 +21,7 @@
   
 org.apache.qpid
 qpid-systests-parent
-8.0.6-SNAPSHOT
+8.0.6
 ../../qpid-systests-parent/pom.xml
   
 
diff --git a/broker-codegen/pom.xml b/broker-codegen/pom.xml
index c3ab944..febddc6 100644
--- a/broker-codegen/pom.xml
+++ b/broker-codegen/pom.xml
@@ -21,7 +21,7 @@
   
 org.apache.qpid
 qpid-broker-parent
-8.0.6-SNAPSHOT
+8.0.6
   
 
   qpid-broker-codegen
diff --git a/broker-core/pom.xml b/broker-core/pom.xml
index 62af2cb..383ed52 100644
--- a/broker-core/pom.xml
+++ b/broker-core/pom.xml
@@ -21,7 +21,7 @@
   
 org.apache.qpid
 qpid-broker-parent
-8.0.6-SNAPSHOT
+8.0.6
   
 
   qpid-broker-core
diff --git a/broker-plugins/access-control/pom.xml 
b/broker-plugins/access-control/pom.xml
index 34c6b47..e7ad76f 100644
--- a/broker-plugins/access-control/pom.xml
+++ b/broker-plugins/access-control/pom.xml
@@ -21,7 +21,7 @@
   
 org.apache.qpid
 

[qpid-protonj2] branch main updated: PROTON-2418 Fix test not being called and update checks

2021-08-24 Thread tabish
This is an automated email from the ASF dual-hosted git repository.

tabish pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/qpid-protonj2.git


The following commit(s) were added to refs/heads/main by this push:
 new f0d8d2d  PROTON-2418 Fix test not being called and update checks
f0d8d2d is described below

commit f0d8d2d8b25f3f908156500138ec864380ab8e28
Author: Timothy Bish 
AuthorDate: Tue Aug 24 13:25:30 2021 -0400

PROTON-2418 Fix test not being called and update checks

Check that the receive call throws when link state becomes closed or
detached during blocked operation.
---
 .../org/apache/qpid/protonj2/client/impl/ReceiverTest.java | 14 +++---
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git 
a/protonj2-client/src/test/java/org/apache/qpid/protonj2/client/impl/ReceiverTest.java
 
b/protonj2-client/src/test/java/org/apache/qpid/protonj2/client/impl/ReceiverTest.java
index f23c639..a753362 100644
--- 
a/protonj2-client/src/test/java/org/apache/qpid/protonj2/client/impl/ReceiverTest.java
+++ 
b/protonj2-client/src/test/java/org/apache/qpid/protonj2/client/impl/ReceiverTest.java
@@ -1292,9 +1292,9 @@ public class ReceiverTest extends 
ImperativeClientTestCase {
 receiver.addCredit(10);
 
 try {
-assertNull(receiver.receive());
+receiver.receive();
+fail("Should throw to indicate that receiver was closed");
 } catch (ClientException ise) {
-// Can happen if receiver closed before the receive call gets 
executed.
 }
 
 connection.closeAsync().get();
@@ -1305,12 +1305,12 @@ public class ReceiverTest extends 
ImperativeClientTestCase {
 
 @Test
 public void testBlockingReceiveCancelledWhenReceiverRemotelyClosed() 
throws Exception {
-doTtestBlockingReceiveCancelledWhenReceiverClosedOrDetached(true);
+
doTtestBlockingReceiveCancelledWhenReceiverRemotelyClosedOrDetached(true);
 }
 
 @Test
 public void testBlockingReceiveCancelledWhenReceiverRemotelyDetached() 
throws Exception {
-doTtestBlockingReceiveCancelledWhenReceiverClosedOrDetached(false);
+
doTtestBlockingReceiveCancelledWhenReceiverRemotelyClosedOrDetached(false);
 }
 
 public void 
doTtestBlockingReceiveCancelledWhenReceiverRemotelyClosedOrDetached(boolean 
close) throws Exception {
@@ -1338,9 +1338,9 @@ public class ReceiverTest extends 
ImperativeClientTestCase {
 receiver.openFuture().get();
 
 try {
-assertNull(receiver.receive());
-} catch (IllegalStateException ise) {
-// Can happen if receiver closed before the receive call gets 
executed.
+receiver.receive();
+fail("Client should throw to indicate remote closed the 
receiver forcibly.");
+} catch (ClientIllegalStateException ise) {
 }
 
 connection.closeAsync().get();

-
To unsubscribe, e-mail: commits-unsubscr...@qpid.apache.org
For additional commands, e-mail: commits-h...@qpid.apache.org



[qpid-protonj2] branch main updated: PROTON-2394 Update to javadocs the ClientMessage constructors

2021-08-24 Thread tabish
This is an automated email from the ASF dual-hosted git repository.

tabish pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/qpid-protonj2.git


The following commit(s) were added to refs/heads/main by this push:
 new 3913c97  PROTON-2394 Update to javadocs the ClientMessage constructors
3913c97 is described below

commit 3913c97bb8e685ddae0ab67958e96889afe4225d
Author: Timothy Bish 
AuthorDate: Tue Aug 24 13:15:28 2021 -0400

PROTON-2394 Update to javadocs the ClientMessage constructors

Changes in the message removed the use of supplier instance and the docs
need to be updated.
---
 .../org/apache/qpid/protonj2/client/impl/ClientMessage.java   | 11 +++
 1 file changed, 3 insertions(+), 8 deletions(-)

diff --git 
a/protonj2-client/src/main/java/org/apache/qpid/protonj2/client/impl/ClientMessage.java
 
b/protonj2-client/src/main/java/org/apache/qpid/protonj2/client/impl/ClientMessage.java
index 3fece03..dcbc8f7 100644
--- 
a/protonj2-client/src/main/java/org/apache/qpid/protonj2/client/impl/ClientMessage.java
+++ 
b/protonj2-client/src/main/java/org/apache/qpid/protonj2/client/impl/ClientMessage.java
@@ -26,7 +26,6 @@ import java.util.Map;
 import java.util.Objects;
 import java.util.function.BiConsumer;
 import java.util.function.Consumer;
-import java.util.function.Supplier;
 
 import org.apache.qpid.protonj2.buffer.ProtonBuffer;
 import org.apache.qpid.protonj2.client.AdvancedMessage;
@@ -62,19 +61,15 @@ public class ClientMessage implements AdvancedMessage 
{
 private int messageFormat;
 
 /**
- * Create a new {@link ClientMessage} instance with no default body 
section or
- * section supplier
- *
- * @param sectionSupplier
- *  A {@link Supplier} that will generate Section values for the 
message body.
+ * Create a new {@link ClientMessage} instance with no default body 
section.
  */
 ClientMessage() {
 this.body = null;
 }
 
 /**
- * Create a new {@link ClientMessage} instance with a {@link Supplier} 
that will
- * provide the AMQP {@link Section} value for any body that is set on the 
message.
+ * Create a new {@link ClientMessage} instance with a {@link Section} 
value that
+ * will comprise the body of this message instance.
  *
  * @param body
  *  The object that comprises the value portion of the body {@link 
Section}.

-
To unsubscribe, e-mail: commits-unsubscr...@qpid.apache.org
For additional commands, e-mail: commits-h...@qpid.apache.org



svn commit: r49624 - /dev/qpid/proton-j/0.33.9-rc1/

2021-08-24 Thread robbie
Author: robbie
Date: Tue Aug 24 16:36:47 2021
New Revision: 49624

Log:
add files for proton-j 0.33.9 (RC1)

Added:
dev/qpid/proton-j/0.33.9-rc1/
dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-bin.tar.gz   (with 
props)
dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-bin.tar.gz.asc   
(with props)
dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-bin.tar.gz.sha512
dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-src.tar.gz   (with 
props)
dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-src.tar.gz.asc   
(with props)
dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-src.tar.gz.sha512

Added: dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-bin.tar.gz
==
Binary file - no diff available.

Propchange: dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-bin.tar.gz
--
svn:mime-type = application/gzip

Added: dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-bin.tar.gz.asc
==
Binary file - no diff available.

Propchange: 
dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-bin.tar.gz.asc
--
svn:mime-type = application/pgp-signature

Added: 
dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-bin.tar.gz.sha512
==
--- dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-bin.tar.gz.sha512 
(added)
+++ dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-bin.tar.gz.sha512 
Tue Aug 24 16:36:47 2021
@@ -0,0 +1 @@
+b69e02549be41173e828b3508f0ac0da2f2ce3534c183605804c2887b5391f2cb65bc99770b89fb557679d9dc1b8918d8a5d2f9718671f977eac25a7efa260b5
  apache-qpid-proton-j-0.33.9-bin.tar.gz

Added: dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-src.tar.gz
==
Binary file - no diff available.

Propchange: dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-src.tar.gz
--
svn:mime-type = application/gzip

Added: dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-src.tar.gz.asc
==
Binary file - no diff available.

Propchange: 
dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-src.tar.gz.asc
--
svn:mime-type = application/pgp-signature

Added: 
dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-src.tar.gz.sha512
==
--- dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-src.tar.gz.sha512 
(added)
+++ dev/qpid/proton-j/0.33.9-rc1/apache-qpid-proton-j-0.33.9-src.tar.gz.sha512 
Tue Aug 24 16:36:47 2021
@@ -0,0 +1 @@
+674a87c1d349ed5bc8f1d8860e1c93083fac8b404558831a84363e53dc8d24f4e1810c88e69a9ef92d0eab65bdb53d60c390caffab6021eb4166f130c5b3eb96
  apache-qpid-proton-j-0.33.9-src.tar.gz



-
To unsubscribe, e-mail: commits-unsubscr...@qpid.apache.org
For additional commands, e-mail: commits-h...@qpid.apache.org



[qpid-proton-j] branch main updated: [maven-release-plugin] prepare for next development iteration

2021-08-24 Thread robbie
This is an automated email from the ASF dual-hosted git repository.

robbie pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/qpid-proton-j.git


The following commit(s) were added to refs/heads/main by this push:
 new 2f26fd8  [maven-release-plugin] prepare for next development iteration
2f26fd8 is described below

commit 2f26fd88f15537dcaa7081fd6bc78197bf5ac2bf
Author: Robbie Gemmell 
AuthorDate: Tue Aug 24 15:56:09 2021 +0100

[maven-release-plugin] prepare for next development iteration
---
 apache-qpid-proton-j/pom.xml  | 2 +-
 examples/engine/pom.xml   | 2 +-
 examples/reactor/pom.xml  | 2 +-
 pom.xml   | 4 ++--
 proton-j/pom.xml  | 2 +-
 tests/performance-jmh/pom.xml | 2 +-
 tests/pom.xml | 2 +-
 7 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/apache-qpid-proton-j/pom.xml b/apache-qpid-proton-j/pom.xml
index 53bf9dc..3ab8957 100644
--- a/apache-qpid-proton-j/pom.xml
+++ b/apache-qpid-proton-j/pom.xml
@@ -18,7 +18,7 @@
   
 org.apache.qpid
 proton-j-parent
-0.33.9
+0.34.0-SNAPSHOT
 ../pom.xml
   
   4.0.0
diff --git a/examples/engine/pom.xml b/examples/engine/pom.xml
index 267c17b..159a701 100644
--- a/examples/engine/pom.xml
+++ b/examples/engine/pom.xml
@@ -19,7 +19,7 @@
   
 org.apache.qpid
 proton-j-parent
-0.33.9
+0.34.0-SNAPSHOT
 ../../pom.xml
   
   4.0.0
diff --git a/examples/reactor/pom.xml b/examples/reactor/pom.xml
index 83e70ca..6a632b8 100644
--- a/examples/reactor/pom.xml
+++ b/examples/reactor/pom.xml
@@ -19,7 +19,7 @@
   
 org.apache.qpid
 proton-j-parent
-0.33.9
+0.34.0-SNAPSHOT
 ../../pom.xml
   
   4.0.0
diff --git a/pom.xml b/pom.xml
index 4bf9edc..89e255f 100644
--- a/pom.xml
+++ b/pom.xml
@@ -26,7 +26,7 @@
 
   org.apache.qpid
   proton-j-parent
-  0.33.9
+  0.34.0-SNAPSHOT
   pom
 
   Proton-J Parent
@@ -204,7 +204,7 @@
 
scm:git:https://gitbox.apache.org/repos/asf/qpid-proton-j.git
 
scm:git:https://gitbox.apache.org/repos/asf/qpid-proton-j.git
 https://gitbox.apache.org/repos/asf?p=qpid-proton-j.git
-0.33.9
+HEAD
   
   
 https://issues.apache.org/jira/browse/PROTON
diff --git a/proton-j/pom.xml b/proton-j/pom.xml
index aeb97fe..df1edfb 100644
--- a/proton-j/pom.xml
+++ b/proton-j/pom.xml
@@ -19,7 +19,7 @@
   
 org.apache.qpid
 proton-j-parent
-0.33.9
+0.34.0-SNAPSHOT
   
   4.0.0
 
diff --git a/tests/performance-jmh/pom.xml b/tests/performance-jmh/pom.xml
index b05c591..400c2bf 100644
--- a/tests/performance-jmh/pom.xml
+++ b/tests/performance-jmh/pom.xml
@@ -19,7 +19,7 @@
 
 org.apache.qpid
 proton-j-parent
-0.33.9
+0.34.0-SNAPSHOT
 ../../pom.xml
 
 4.0.0
diff --git a/tests/pom.xml b/tests/pom.xml
index 872b03f..cce274c 100644
--- a/tests/pom.xml
+++ b/tests/pom.xml
@@ -23,7 +23,7 @@
   
 org.apache.qpid
 proton-j-parent
-0.33.9
+0.34.0-SNAPSHOT
   
 
   proton-tests

-
To unsubscribe, e-mail: commits-unsubscr...@qpid.apache.org
For additional commands, e-mail: commits-h...@qpid.apache.org



[qpid-proton-j] annotated tag 0.33.9 created (now b0b28e0)

2021-08-24 Thread robbie
This is an automated email from the ASF dual-hosted git repository.

robbie pushed a change to annotated tag 0.33.9
in repository https://gitbox.apache.org/repos/asf/qpid-proton-j.git.


  at b0b28e0  (tag)
 tagging 13d60de7243058dd6537fe2593adcce481ffe939 (commit)
 replaces 0.33.8
  by Robbie Gemmell
  on Tue Aug 24 15:55:59 2021 +0100

- Log -
[maven-release-plugin] copy for tag 0.33.9
---

No new revisions were added by this update.

-
To unsubscribe, e-mail: commits-unsubscr...@qpid.apache.org
For additional commands, e-mail: commits-h...@qpid.apache.org



[qpid-proton-j] branch main updated: [maven-release-plugin] prepare release 0.33.9

2021-08-24 Thread robbie
This is an automated email from the ASF dual-hosted git repository.

robbie pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/qpid-proton-j.git


The following commit(s) were added to refs/heads/main by this push:
 new 13d60de  [maven-release-plugin] prepare release 0.33.9
13d60de is described below

commit 13d60de7243058dd6537fe2593adcce481ffe939
Author: Robbie Gemmell 
AuthorDate: Tue Aug 24 15:54:27 2021 +0100

[maven-release-plugin] prepare release 0.33.9
---
 apache-qpid-proton-j/pom.xml  | 2 +-
 examples/engine/pom.xml   | 2 +-
 examples/reactor/pom.xml  | 2 +-
 pom.xml   | 4 ++--
 proton-j/pom.xml  | 2 +-
 tests/performance-jmh/pom.xml | 2 +-
 tests/pom.xml | 2 +-
 7 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/apache-qpid-proton-j/pom.xml b/apache-qpid-proton-j/pom.xml
index 3ab8957..53bf9dc 100644
--- a/apache-qpid-proton-j/pom.xml
+++ b/apache-qpid-proton-j/pom.xml
@@ -18,7 +18,7 @@
   
 org.apache.qpid
 proton-j-parent
-0.34.0-SNAPSHOT
+0.33.9
 ../pom.xml
   
   4.0.0
diff --git a/examples/engine/pom.xml b/examples/engine/pom.xml
index 159a701..267c17b 100644
--- a/examples/engine/pom.xml
+++ b/examples/engine/pom.xml
@@ -19,7 +19,7 @@
   
 org.apache.qpid
 proton-j-parent
-0.34.0-SNAPSHOT
+0.33.9
 ../../pom.xml
   
   4.0.0
diff --git a/examples/reactor/pom.xml b/examples/reactor/pom.xml
index 6a632b8..83e70ca 100644
--- a/examples/reactor/pom.xml
+++ b/examples/reactor/pom.xml
@@ -19,7 +19,7 @@
   
 org.apache.qpid
 proton-j-parent
-0.34.0-SNAPSHOT
+0.33.9
 ../../pom.xml
   
   4.0.0
diff --git a/pom.xml b/pom.xml
index 89e255f..4bf9edc 100644
--- a/pom.xml
+++ b/pom.xml
@@ -26,7 +26,7 @@
 
   org.apache.qpid
   proton-j-parent
-  0.34.0-SNAPSHOT
+  0.33.9
   pom
 
   Proton-J Parent
@@ -204,7 +204,7 @@
 
scm:git:https://gitbox.apache.org/repos/asf/qpid-proton-j.git
 
scm:git:https://gitbox.apache.org/repos/asf/qpid-proton-j.git
 https://gitbox.apache.org/repos/asf?p=qpid-proton-j.git
-HEAD
+0.33.9
   
   
 https://issues.apache.org/jira/browse/PROTON
diff --git a/proton-j/pom.xml b/proton-j/pom.xml
index df1edfb..aeb97fe 100644
--- a/proton-j/pom.xml
+++ b/proton-j/pom.xml
@@ -19,7 +19,7 @@
   
 org.apache.qpid
 proton-j-parent
-0.34.0-SNAPSHOT
+0.33.9
   
   4.0.0
 
diff --git a/tests/performance-jmh/pom.xml b/tests/performance-jmh/pom.xml
index 400c2bf..b05c591 100644
--- a/tests/performance-jmh/pom.xml
+++ b/tests/performance-jmh/pom.xml
@@ -19,7 +19,7 @@
 
 org.apache.qpid
 proton-j-parent
-0.34.0-SNAPSHOT
+0.33.9
 ../../pom.xml
 
 4.0.0
diff --git a/tests/pom.xml b/tests/pom.xml
index cce274c..872b03f 100644
--- a/tests/pom.xml
+++ b/tests/pom.xml
@@ -23,7 +23,7 @@
   
 org.apache.qpid
 proton-j-parent
-0.34.0-SNAPSHOT
+0.33.9
   
 
   proton-tests

-
To unsubscribe, e-mail: commits-unsubscr...@qpid.apache.org
For additional commands, e-mail: commits-h...@qpid.apache.org
diff --git 
a/protonj2/src/main/java/org/apache/qpid/protonj2/buffer/ProtonBuffer.java 
b/protonj2/src/main/java/org/apache/qpid/protonj2/buffer/ProtonBuffer.java
index f729cdc..c9afd8f 100644
--- a/protonj2/src/main/java/org/apache/qpid/protonj2/buffer/ProtonBuffer.java
+++ b/protonj2/src/main/java/org/apache/qpid/protonj2/buffer/ProtonBuffer.java
@@ -90,7 +90,8 @@ public interface ProtonBuffer extends 
Comparable {
 /**
  * Ensures that the requested number of bytes is available for write 
operations
  * in the current buffer, growing the buffer if needed to meet the 
requested
- * writable capacity.
+ * writable capacity. This method will not alter the write offset but may 
change
+ * the value returned from the capacity method if new buffer space is 
allocated.
  *
  * @param amount
  *  The number of bytes beyond the current write index needed.
@@ -166,8 +167,9 @@ public interface ProtonBuffer extends 
Comparable {
 ProtonBuffer copy(int index, int length);
 
 /**
- * Reset the position markers of this buffer, this method is not required 
to reset
- * the data previously written to this buffer.
+ * Reset the read and write offsets to zero and clears the position 
markers if
+ * set previously, this method is not required to reset the data previously
+ * written to this buffer.
  *
  * @return this buffer for using in call chaining.
  */
@@ -547,8 +549,8 @@ public interface ProtonBuffer extends 
Comparable {
  *  The index into the buffer where the value should be read.
  * @param destination
  *  The buffer where the bytes read will be written to
  * @param destinationIndex
  *  The index into the destination where the write starts
  * @param length
  *  The number of bytes to transfer
  *
@@ -562,7 +564,7 @@ public interface ProtonBuffer extends 
Comparable {
  * if {@code dstIndex + length} is greater than
  *{@code dst.capacity}
  */
-ProtonBuffer getBytes(int index, ProtonBuffer destination, int 
destinationIndex, int length);
+ProtonBuffer getBytes(int index, ProtonBuffer destination, int offset, int 
length);
 
 /**
  * Transfers this buffer's data to the specified destination starting at
@@ -642,7 +644,7 @@ public interface ProtonBuffer extends 
Comparable {
  *
  * @return a reference to this ProtonBuffer for chaining.
  *
- * @throws IndexOutOfBoundsException if the index is negative or the write 
would exceed capcity.
+ * @throws IndexOutOfBoundsException if the index is negative or the write 
would exceed capacity.
  */
 ProtonBuffer setByte(int index, int value);
 
@@ -656,7 +658,7 @@ public interface ProtonBuffer extends 
Comparable {
  *
  * @return a reference to this ProtonBuffer for chaining.
  *
- * @throws IndexOutOfBoundsException if the index is negative or the write 
would exceed capcity.
+ * @throws IndexOutOfBoundsException if the index is negative or the write 
would exceed capacity.
  */
 ProtonBuffer setBoolean(int index, boolean value);
 
@@ -670,7 +672,7 @@ public interface ProtonBuffer extends 
Comparable {
  *
  * @return a reference to this ProtonBuffer for chaining.
  *
- * @throws IndexOutOfBoundsException if the index is negative or the write 
would exceed capcity.
+ * @throws IndexOutOfBoundsException if the index is negative or the write 
would exceed capacity.
  */
 ProtonBuffer setChar(int index, int value);
 
@@ -684,7 +686,7 @@ public interface ProtonBuffer extends 
Comparable {
  *
  * @return a reference to this ProtonBuffer for chaining.
  *
- * @throws IndexOutOfBoundsException if the index is negative or the write 
would exceed capcity.
+ * @throws IndexOutOfBoundsException if the index is negative or the write 
would exceed capacity.
  */
 ProtonBuffer setShort(int index, int value);
 
@@ -698,7 +700,7 @@ public interface 

[qpid-protonj2] branch main updated: PROTON-2420 Fix some minor code issues found with static analysis

2021-08-24 Thread tabish
This is an automated email from the ASF dual-hosted git repository.

tabish pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/qpid-protonj2.git


The following commit(s) were added to refs/heads/main by this push:
 new f28bc42  PROTON-2420 Fix some minor code issues found with static 
analysis
f28bc42 is described below

commit f28bc429f9b3b481e3f36ea7bbc23b1def5cd404
Author: Timothy Bish 
AuthorDate: Tue Aug 24 16:32:46 2021 -0400

PROTON-2420 Fix some minor code issues found with static analysis
---
 .../qpid/protonj2/client/TransportOptions.java  | 21 +
 .../protonj2/client/transport/NettyIOContext.java   |  2 +-
 .../qpid/protonj2/client/SaslOptionsTest.java   |  4 ++--
@@ -547,8 +549,8 @@ public interface ProtonBuffer extends 
  * @param destination
  *  The buffer where the bytes read will be written to
- * @param destinationIndex
- *  The index into the destination where the write starts
+ * @param offset
+ *  The offset into the destination where the write starts
  * @param length
  *  The number of bytes to transfer
 .../qpid/protonj2/client/TransportOptionsTest.java  | 18 ++
 .../qpid/protonj2/client/impl/ConnectionTest.java   |  2 +-
 .../qpid/protonj2/client/impl/ReceiverTest.java |  8 
 .../protonj2/client/transport/TcpTransportTest.java |  8 
 .../qpid/protonj2/test/driver/DriverSessions.java   |  4 ++--
 .../qpid/protonj2/test/driver/FrameDecoder.java |  4 ++--
 .../test/driver/codec/primitives/Binary.java|  2 +-
 .../test/driver/codec/transport/Attach.java |  1 +
 .../protonj2/test/driver/codec/transport/Open.java  |  4 ++--
 .../driver/codec/transport/ReceiverSettleMode.java  |  2 +-
 .../driver/codec/transport/SenderSettleMode.java|  2 +-
 .../test/driver/expectations/AttachExpectation.java |  2 +-
 .../test/driver/expectations/DetachExpectation.java |  4 ++--
 .../driver/expectations/DispositionExpectation.java |  2 +-
 .../test/driver/expectations/FlowExpectation.java   |  2 +-
 .../driver/expectations/TransferExpectation.java|  2 +-
 .../qpid/protonj2/types/messaging/Target.java   |  2 +-
 .../types/messaging/TerminusExpiryPolicy.java   |  3 ++-
 .../types/transport/ReceiverSettleMode.java |  2 +-
 .../protonj2/types/transport/SenderSettleMode.java  |  2 +-
 .../protonj2/buffer/util/ProtonTestByteBuffer.java  |  4 ++--
 24 files changed, 58 insertions(+), 49 deletions(-)
